import os
import sys
from collections import OrderedDict
# import the cython module
import mmseqs_parser_c


########### FUNCTIONS ############
def get_params():
    """Parse and analyse command line parameters."""
    import argparse
    parser_usage = '\nProvide an input file generated using mmseqs2 and converted into BLASTP compatible tab-separated format.\nOutputs a file of ortholog and paralogs that can be processed by InParanoid.\n'
    parser = argparse.ArgumentParser(description='mmseqs2 parser 0.1', usage=parser_usage)
    #start adding the command line options
    parser.add_argument('-i', '--input', type=str, required=False, help='Tab-separated alignment file generated using mmseqs2 and converted in BLASTP tab-separated format.\nNOTE: for details on the fields contained in the output refer to function inparanoid_like_parser', default=None)
    parser.add_argument('-q', '--query', type=str, required=True, help='FASTA file with the query proteins.', default=None)
    parser.add_argument('-t', '--db', type=str, required=True, help='FASTA file with the target proteins.', default=None)
    parser.add_argument('-o', '--output', type=str, required=True, help='File in which the output will be stored.', default=None)
    parser.add_argument('-c', '--cutoff', type=int, required=False, help='Cutoff score (sum of hsp bitscores for each hit) for alignments.', default=40)
    parser.add_argument('-d', '--debug', required=False, help='Output debug information.\nNOTE: this is not used when the input is STDIN.', default=False, action='store_true')
    args = parser.parse_args()
    return (args, parser)


########### MAIN ############
def main():
    #Get the parameters
    args = get_params()[0]
    debug = args.debug
    inputPath = '%s'%os.path.realpath(args.input)
    queryPath = '%s'%os.path.realpath(args.query)
    targetPath = '%s'%os.path.realpath(args.db)
    outPath = '%s'%os.path.realpath(args.output)
    cutoff = args.cutoff
    outName = os.path.basename(outPath)
    outDir = os.path.dirname(outPath)


    if debug:
        print('Alignment file:\t%s'%inputPath)
        print('Query file:\t%s'%queryPath)
        print('Target file:\t%s'%targetPath)
        print('Output file:\t%s'%outPath)
        print('Cutoff:\t%s'%str(cutoff))

    mmseqs_parser_c.inparanoid_like_parser_mmseqs(inputPath, queryPath, targetPath, outDir=outDir, outName=outName, scoreCoff=cutoff, debug=debug)

if __name__ == "__main__":
    main()
